@@ -37,8 +37,7 @@ dependencies = {
             'item': 'watson.routing.routers.DictRouter',
             'init':
             [lambda container: container.get(
-             'application.config').get('routes',
-                                       {})]
+             'application.config').get('routes', None)]
         },
         'profiler': {
             'item': 'watson.framework.debug.profilers.Profiler',
@@ -146,6 +145,10 @@ session = {
     }
 }
 
+exceptions = {
+    'class': 'watson.framework.exceptions.ApplicationError'
+}
+
 # Application event settings
 events = {
     events.EXCEPTION: [('app_exception_listener',)],
